[gnome-software] Rename "Software Sources" to "Software Repositories"



commit 3bbf72c079ba6f4b864b7cd223e0cc5592380e2a
Author: Kalev Lember <klember redhat com>
Date:   Fri Feb 9 13:48:06 2018 +0100

    Rename "Software Sources" to "Software Repositories"
    
    This keeps the terminology aligned with DNF and Cockpit, which both use
    the term "repository".

 src/gnome-software.ui   |  2 +-
 src/gs-common.c         |  9 ++++-----
 src/gs-details-page.c   |  2 +-
 src/gs-details-page.ui  | 14 +++++++-------
 src/gs-menus.ui         |  2 +-
 src/gs-overview-page.c  |  2 +-
 src/gs-overview-page.ui |  2 +-
 src/gs-repos-dialog.c   | 22 +++++++++++-----------
 src/gs-repos-dialog.ui  |  6 +++---
 9 files changed, 30 insertions(+), 31 deletions(-)
---
diff --git a/src/gnome-software.ui b/src/gnome-software.ui
index c551ceb4..91f3fadf 100644
--- a/src/gnome-software.ui
+++ b/src/gnome-software.ui
@@ -347,7 +347,7 @@
                         <property name="visible">True</property>
                         <child>
                           <object class="GtkButton" id="button_events_sources">
-                            <property name="label" translatable="yes" comments="button in the info 
bar">Software Sources</property>
+                            <property name="label" translatable="yes" comments="button in the info 
bar">Software Repositories</property>
                             <property name="can_focus">True</property>
                             <property name="receives_default">True</property>
                           </object>
diff --git a/src/gs-details-page.c b/src/gs-details-page.c
index 1669a0c8..800bc596 100644
--- a/src/gs-details-page.c
+++ b/src/gs-details-page.c
@@ -327,7 +327,7 @@ gs_details_page_switch_to (GsPage *page, gboolean scroll_up)
                        /* TRANSLATORS: this is a button that allows the apps to
                         * be installed.
                         * The ellipsis indicates that further steps are required,
-                        * e.g. enabling software sources or the like */
+                        * e.g. enabling software repositories or the like */
                        gtk_button_set_label (GTK_BUTTON (self->button_install), _("_Install…"));
                }
                break;
diff --git a/src/gs-details-page.ui b/src/gs-details-page.ui
index 22d3efdf..5adc0322 100644
--- a/src/gs-details-page.ui
+++ b/src/gs-details-page.ui
@@ -490,8 +490,8 @@
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
                             <property name="margin_top">20</property>
-                            <property name="title" translatable="yes">Software Source Included</property>
-                            <property name="body" translatable="yes">This application includes a software 
source which provides updates, as well as access to other software.</property>
+                            <property name="title" translatable="yes">Software Repository Included</property>
+                            <property name="body" translatable="yes">This application includes a software 
repository which provides updates, as well as access to other software.</property>
                           </object>
                           <packing>
                             <property name="expand">False</property>
@@ -504,8 +504,8 @@
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
                             <property name="margin_top">20</property>
-                            <property name="title" translatable="yes">No Software Source Included</property>
-                            <property name="body" translatable="yes">This application does not include a 
software source. It will not be updated with new versions.</property>
+                            <property name="title" translatable="yes">No Software Repository 
Included</property>
+                            <property name="body" translatable="yes">This application does not include a 
software repository. It will not be updated with new versions.</property>
                           </object>
                           <packing>
                             <property name="expand">False</property>
@@ -532,9 +532,9 @@
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
                             <property name="margin_top">20</property>
-                            <property name="title" translatable="yes" comments="Translators: a repository 
file used for installing software has been discovered.">Software Source Identified</property>
-                            <property name="body" translatable="yes">Adding this software source will give 
you access to additional software and upgrades.</property>
-                            <property name="warning" translatable="yes">Only use software sources that you 
trust.</property>
+                            <property name="title" translatable="yes" comments="Translators: a repository 
file used for installing software has been discovered.">Software Repository Identified</property>
+                            <property name="body" translatable="yes">Adding this software repository will 
give you access to additional software and upgrades.</property>
+                            <property name="warning" translatable="yes">Only use software repositories that 
you trust.</property>
                           </object>
                           <packing>
                             <property name="expand">False</property>
diff --git a/src/gs-menus.ui b/src/gs-menus.ui
index af7f63bc..4ca62b7c 100644
--- a/src/gs-menus.ui
+++ b/src/gs-menus.ui
@@ -4,7 +4,7 @@
   <menu id="app-menu">
     <section>
       <item>
-        <attribute name="label" translatable="yes">_Software Sources</attribute>
+        <attribute name="label" translatable="yes">_Software Repositories</attribute>
         <attribute name="action">app.sources</attribute>
         <attribute name="hidden-when">action-disabled</attribute>
       </item>
diff --git a/src/gs-overview-page.c b/src/gs-overview-page.c
index fd4d26f0..a5b2cf0b 100644
--- a/src/gs-overview-page.c
+++ b/src/gs-overview-page.c
@@ -903,7 +903,7 @@ gs_overview_page_setup (GsPage *page,
        /* create info bar if not already dismissed in initial-setup */
        gs_overview_page_refresh_proprietary (self);
        gtk_info_bar_add_button (GTK_INFO_BAR (priv->infobar_proprietary),
-                                /* TRANSLATORS: button to turn on proprietary software sources */
+                                /* TRANSLATORS: button to turn on proprietary software repositories */
                                 _("Enable"), GTK_RESPONSE_YES);
        g_signal_connect (priv->infobar_proprietary, "response",
                          G_CALLBACK (gs_overview_page_proprietary_response_cb), self);
diff --git a/src/gs-overview-page.ui b/src/gs-overview-page.ui
index 14f77bba..1b341ac7 100644
--- a/src/gs-overview-page.ui
+++ b/src/gs-overview-page.ui
@@ -46,7 +46,7 @@
                         <property name="visible">True</property>
                         <property name="can_focus">False</property>
                         <property name="halign">start</property>
-                        <property name="label" translatable="yes">Enable Proprietary Software 
Sources?</property>
+                        <property name="label" translatable="yes">Enable Proprietary Software 
Repositories?</property>
                         <attributes>
                           <attribute name="weight" value="bold"/>
                         </attributes>
diff --git a/src/gs-repos-dialog.ui b/src/gs-repos-dialog.ui
index 0f8b767d..e144e8b9 100644
--- a/src/gs-repos-dialog.ui
+++ b/src/gs-repos-dialog.ui
@@ -3,7 +3,7 @@
   <requires lib="gtk+" version="3.10"/>
   <template class="GsReposDialog" parent="GtkDialog">
     <property name="can_focus">False</property>
-    <property name="title" translatable="yes">Software Sources</property>
+    <property name="title" translatable="yes">Software Repositories</property>
     <property name="modal">True</property>
     <property name="default_width">460</property>
     <property name="default_height">500</property>
@@ -43,7 +43,7 @@
           <object class="GtkLabel" id="label_header">
             <property name="can_focus">False</property>
             <property name="visible">True</property>
-            <property name="label" translatable="yes">Software Sources</property>
+            <property name="label" translatable="yes">Software Repositories</property>
             <property name="selectable">False</property>
             <style>
               <class name="title"/>
@@ -158,7 +158,7 @@
                     <property name="visible">True</property>
                     <property name="can_focus">False</property>
                     <property name="xalign">0</property>
-                    <property name="label" translatable="yes">Additional Sources</property>
+                    <property name="label" translatable="yes">Additional Repositories</property>
                     <property name="wrap">True</property>
                     <property name="max_width_chars">30</property>
                     <attributes>


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gs-common.c b/src/gs-common.c
index 995d7fa1..0f7f20b3 100644
--- a/src/gs-common.c
+++ b/src/gs-common.c
@@ -211,7 +211,7 @@ gs_app_notify_unavailable (GsApp *app, GtkWindow *parent)
        } else {
                g_string_append_printf (title, "<b>%s</b>",
                                        /* TRANSLATORS: window title */
-                                       _("Enable Third-Party Software Source?"));
+                                       _("Enable Third-Party Software Repository?"));
        }
        dialog = gtk_message_dialog_new (parent,
                                         GTK_DIALOG_MODAL,
@@ -227,7 +227,7 @@ gs_app_notify_unavailable (GsApp *app, GtkWindow *parent)
                g_string_append_printf (body,
                                        /* TRANSLATORS: the replacements are as follows:
                                         * 1. Application name, e.g. "Firefox"
                                         * 2. Software source name, e.g. fedora-optional
                                         */
                                        _("%s is not <a 
href=\"https://en.wikipedia.org/wiki/Free_and_open-source_software\";>"
                                          "free and open source software</a>, "
@@ -238,7 +238,7 @@ gs_app_notify_unavailable (GsApp *app, GtkWindow *parent)
                g_string_append_printf (body,
                                        /* TRANSLATORS: the replacements are as follows:
                                         * 1. Application name, e.g. "Firefox"
                                         * 2. Software source name, e.g. fedora-optional */
                                        _("%s is provided by “%s”."),
                                        gs_app_get_name (app),
                                        origin_url);
@@ -248,8 +248,7 @@ gs_app_notify_unavailable (GsApp *app, GtkWindow *parent)
        if (!already_enabled) {
                g_string_append (body, " ");
                g_string_append (body,
-                               /* TRANSLATORS: a software source is a repo */
-                               _("This software source must be "
+                               _("This software repository must be "
                                  "enabled to continue installation."));
        }
 
@@ -227,7 +227,7 @@ gs_app_notify_unavailable (GsApp *app, GtkWindow *parent)
                                        /* TRANSLATORS: the replacements are as follows:
                                         * 1. Application name, e.g. "Firefox"
-                                        * 2. Software source name, e.g. fedora-optional
+                                        * 2. Software repository name, e.g. fedora-optional
                                         */
                                        _("%s is not <a 
@@ -238,7 +238,7 @@ gs_app_notify_unavailable (GsApp *app, GtkWindow *parent)
                                        /* TRANSLATORS: the replacements are as follows:
                                         * 1. Application name, e.g. "Firefox"
-                                        * 2. Software source name, e.g. fedora-optional */
+                                        * 2. Software repository name, e.g. fedora-optional */
                                        _("%s is provided by “%s”."),
                                        gs_app_get_name (app),
diff --git a/src/gs-repos-dialog.c b/src/gs-repos-dialog.c
index 7f52f84e..101a4a7e 100644
--- a/src/gs-repos-dialog.c
+++ b/src/gs-repos-dialog.c
@@ -104,39 +104,39 @@ get_source_installed_text (GPtrArray *sources)
 
        /* nothing! */
        if (cnt_apps == 0 && cnt_addon == 0) {
                /* TRANSLATORS: This string describes a software source that
                   has no software installed from it. */
                return g_strdup (_("No applications or addons installed; other software might still be"));
        }
        if (cnt_addon == 0) {
                /* TRANSLATORS: This string is used to construct the 'X applications
-                  installed' sentence, describing a software source. */
+                  installed' sentence, describing a software repository. */
                return g_strdup_printf (ngettext ("%u application installed",
                                                  "%u applications installed",
                                                  cnt_apps), cnt_apps);
        }
        if (cnt_apps == 0) {
                /* TRANSLATORS: This string is used to construct the 'X add-ons
-                  installed' sentence, describing a software source. */
+                  installed' sentence, describing a software repository. */
                return g_strdup_printf (ngettext ("%u add-on installed",
                                                  "%u add-ons installed",
                                                  cnt_addon), cnt_addon);
        }
 
        /* TRANSLATORS: This string is used to construct the 'X applications
-          and y add-ons installed' sentence, describing a software source.
+          and y add-ons installed' sentence, describing a software repository.
           The correct form here depends on the number of applications. */
        apps_text = g_strdup_printf (ngettext ("%u application",
                                               "%u applications",
                                               cnt_apps), cnt_apps);
        /* TRANSLATORS: This string is used to construct the 'X applications
-          and y add-ons installed' sentence, describing a software source.
+          and y add-ons installed' sentence, describing a software repository.
           The correct form here depends on the number of add-ons. */
        addons_text = g_strdup_printf (ngettext ("%u add-on",
                                                 "%u add-ons",
                                                 cnt_addon), cnt_addon);
        /* TRANSLATORS: This string is used to construct the 'X applications
-          and y add-ons installed' sentence, describing a software source.
+          and y add-ons installed' sentence, describing a software repository.
           The correct form here depends on the total number of
           applications and add-ons. */
        return g_strdup_printf (ngettext ("%s and %s installed",
@@ -394,7 +394,7 @@ reload_sources (GsReposDialog *dialog)
        gtk_widget_hide (dialog->button_back);
        gs_container_remove_all (GTK_CONTAINER (dialog->listbox));
 
        /* get the list of non-core software sources */
        plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_SOURCES,
                                         "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
                                         "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_RELATED,
@@ -676,15 +676,15 @@ gs_repos_dialog_init (GsReposDialog *dialog)
                          dialog);
        gs_repos_dialog_row_set_name (GS_REPOS_DIALOG_ROW (dialog->row_proprietary),
                                      /* TRANSLATORS: list header */
-                                     _("Proprietary Software Sources"));
+                                     _("Proprietary Software Repositories"));
        gs_repos_dialog_row_set_switch_enabled (GS_REPOS_DIALOG_ROW (dialog->row_proprietary), TRUE);
        gs_repos_dialog_refresh_proprietary_apps (dialog);
 
        os_name = get_os_name ();
-       /* TRANSLATORS: This is the text displayed in the Software Sources
-          dialog when no OS-provided software sources are enabled. %s gets
+       /* TRANSLATORS: This is the text displayed in the Software Repositories
+          dialog when no OS-provided software repositories are enabled. %s gets
           replaced by the name of the actual distro, e.g. Fedora. */
-       label_text = g_strdup_printf (_("Software sources can be downloaded from the internet. They give you 
access to additional software that is not provided by %s."),
+       label_text = g_strdup_printf (_("Software repositories can be downloaded from the internet. They give 
you access to additional software that is not provided by %s."),
                                      os_name);
        gtk_label_set_text (GTK_LABEL (dialog->label_empty), label_text);
@@ -104,39 +104,39 @@ get_source_installed_text (GPtrArray *sources)
        /* nothing! */
        if (cnt_apps == 0 && cnt_addon == 0) {
-               /* TRANSLATORS: This string describes a software source that
+               /* TRANSLATORS: This string describes a software repository that
                   has no software installed from it. */
                return g_strdup (_("No applications or addons installed; other software might still be"));
@@ -394,7 +394,7 @@ reload_sources (GsReposDialog *dialog)
        gs_container_remove_all (GTK_CONTAINER (dialog->listbox));
 
-       /* get the list of non-core software sources */
+       /* get the list of non-core software repositories */
        plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_SOURCES,
                                         "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 